Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / herkules / Herkules.py | (no class) |  | 97% | 143 | 4 | 38 |  | 95% | 80 | 4 |  | 96%
tests / test_beetle.py | TestBeetle |  | 97% | 236 | 7 | 0 |  | 100% | 8 | 0 |  | 97%
Total |  |  | 98% | 487 | 11 | 38 |  | 96% | 94 | 4 |  | 97%

No items found using the specified filter.

1 class skipped due to complete coverage.